Protectable Plugins
-------------------

Project
^^^^^^^

.. autoclass:: karbor.services.protection.protectable_plugins.project.ProjectProtectablePlugin()
  :members:
  :show-inheritance:

Server
^^^^^^

.. autoclass:: karbor.services.protection.protectable_plugins.server.ServerProtectablePlugin()
  :members:
  :show-inheritance:

Volume
^^^^^^

.. autoclass:: karbor.services.protection.protectable_plugins.volume.VolumeProtectablePlugin()
  :members:
  :show-inheritance:

Image
^^^^^

.. autoclass:: karbor.services.protection.protectable_plugins.image.ImageProtectablePlugin()
  :members:
  :show-inheritance:


